@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2015-04-21'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2015-04-22'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,6 +76,10 @@ sub _add_arg {
         $arg_spec->{cmdline_aliases} = $args{aliases};
     }
 
+    if (defined $args{pos}) {
+        $arg_spec->{pos} = $args{pos};
+    }
+
     # translation args
     my %xargs = (field => $fname);
 
@@ -231,6 +235,7 @@ _
         cat_name    => 'filtering',
         cat_text    => N__('filtering'),
         summary     => N__("Search"),
+        pos         => 0,
     ) if $opts->{enable_filtering} && $opts->{enable_search};
 
     # add filter arguments for each table field
@@ -602,7 +607,7 @@ sub __parse_query {
     my $ci = $opts->{case_insensitive_search};
     my $search_opts = {ci => $ci};
     my $search_re;
-    my $q = $args->{q};
+    my $q = $args->{query};
     if (defined $q) {
         if ($opts->{word_search}) {
             $search_re = $ci ? qr/\b$q\b/i : qr/\b$q\b/;
@@ -610,7 +615,7 @@ sub __parse_query {
             $search_re = $ci ? qr/$q/i : qr/$q/;
         }
     }
-    $query->{q} = $args->{q};
+    $query->{query} = $args->{query};
     $query->{search_opts} = $args->{search_opts};
     unless ($opts->{custom_search}) {
         $query->{search_fields} = \@searchable_fields;
@@ -744,7 +749,7 @@ sub _gen_func {
         no warnings; # silence undef warnings when comparing record values
 
         $log->tracef("(read_table_func) Filtering ...");
-        my $q = $query->{q};
+        my $q = $query->{query};
         my $search_re = $query->{search_re};
 
         if (grep { $_->[1] eq 'date' } @{ $query->{filters} }) {
@@ -1467,7 +1472,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.46 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-04-21.
+This document describes version 0.47 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-04-22.
 
 =head1 SYNOPSIS
 
